==> anjuta-2.25.90.tar.gz: anjuta-2.25.90/libanjuta/anjuta-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "anjuta-enum-types.h"

/* enumerations from "anjuta-shell.h" */
GType
anjuta_shell_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_SHELL_ERROR_DOESNT_EXIST, "ANJUTA_SHELL_ERROR_DOESNT_EXIST", "exist" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaShellError"), values);
  }
  return etype;
}
GType
anjuta_shell_placement_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_SHELL_PLACEMENT_NONE, "ANJUTA_SHELL_PLACEMENT_NONE", "none" },
      { ANJUTA_SHELL_PLACEMENT_TOP, "ANJUTA_SHELL_PLACEMENT_TOP", "top" },
      { ANJUTA_SHELL_PLACEMENT_BOTTOM, "ANJUTA_SHELL_PLACEMENT_BOTTOM", "bottom" },
      { ANJUTA_SHELL_PLACEMENT_RIGHT, "ANJUTA_SHELL_PLACEMENT_RIGHT", "right" },
      { ANJUTA_SHELL_PLACEMENT_LEFT, "ANJUTA_SHELL_PLACEMENT_LEFT", "left" },
      { ANJUTA_SHELL_PLACEMENT_CENTER, "ANJUTA_SHELL_PLACEMENT_CENTER", "center" },
      { ANJUTA_SHELL_PLACEMENT_FLOATING, "ANJUTA_SHELL_PLACEMENT_FLOATING", "floating" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaShellPlacement"), values);
  }
  return etype;
}

/* enumerations from "anjuta-convert.h" */
GType
anjuta_convert_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_CONVERT_ERROR_AUTO_DETECTION_FAILED, "ANJUTA_CONVERT_ERROR_AUTO_DETECTION_FAILED", "failed" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaConvertError"), values);
  }
  return etype;
}

/* enumerations from "anjuta-plugin-description.h" */
GType
anjuta_plugin_description_parse_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_SYNTAX, "ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_SYNTAX", "syntax" },
      { ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_ESCAPES, "ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_ESCAPES", "escapes" },
      { ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_CHARS, "ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_CHARS", "chars" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPluginDescriptionParseError"), values);
  }
  return etype;
}

/* enumerations from "anjuta-plugin-manager.h" */
GType
anjuta_plugin_manager_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY, "ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY", "missing-factory" },
      { ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN, "ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN", "error-unknown" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPluginManagerError"), values);
  }
  return etype;
}

/* enumerations from "anjuta-profile.h" */
GType
anjuta_profile_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PROFILE_ERROR_URI_READ_FAILED, "ANJUTA_PROFILE_ERROR_URI_READ_FAILED", "read-failed" },
      { ANJUTA_PROFILE_ERROR_URI_WRITE_FAILED, "ANJUTA_PROFILE_ERROR_URI_WRITE_FAILED", "write-failed" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaProfileError"), values);
  }
  return etype;
}

/* enumerations from "anjuta-preferences.h" */
GType
anjuta_property_object_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE, "ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE", "toggle" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_SPIN, "ANJUTA_PROPERTY_OBJECT_TYPE_SPIN", "spin" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY, "ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY", "entry" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_COMBO, "ANJUTA_PROPERTY_OBJECT_TYPE_COMBO", "combo" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_TEXT, "ANJUTA_PROPERTY_OBJECT_TYPE_TEXT", "text" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_COLOR, "ANJUTA_PROPERTY_OBJECT_TYPE_COLOR", "color" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_FONT, "ANJUTA_PROPERTY_OBJECT_TYPE_FONT", "font" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_FILE, "ANJUTA_PROPERTY_OBJECT_TYPE_FILE", "file" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_FOLDER, "ANJUTA_PROPERTY_OBJECT_TYPE_FOLDER", "folder" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPropertyObjectType"), values);
  }
  return etype;
}
GType
anjuta_property_data_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PROPERTY_DATA_TYPE_BOOL, "ANJUTA_PROPERTY_DATA_TYPE_BOOL", "bool" },
      { ANJUTA_PROPERTY_DATA_TYPE_INT, "ANJUTA_PROPERTY_DATA_TYPE_INT", "int" },
      { ANJUTA_PROPERTY_DATA_TYPE_TEXT, "ANJUTA_PROPERTY_DATA_TYPE_TEXT", "text" },
      { ANJUTA_PROPERTY_DATA_TYPE_COLOR, "ANJUTA_PROPERTY_DATA_TYPE_COLOR", "color" },
      { ANJUTA_PROPERTY_DATA_TYPE_FONT, "ANJUTA_PROPERTY_DATA_TYPE_FONT", "font" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPropertyDataType"), values);
  }
  return etype;
}
GType
anjuta_preferences_filter_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PREFERENCES_FILTER_NONE, "ANJUTA_PREFERENCES_FILTER_NONE", "none" },
      { ANJUTA_PREFERENCES_FILTER_PROJECT, "ANJUTA_PREFERENCES_FILTER_PROJECT", "project" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPreferencesFilterType"), values);
  }
  return etype;
}

/* enumerations from "anjuta-launcher.h" */
GType
anjuta_launcher_output_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_LAUNCHER_OUTPUT_STDOUT, "ANJUTA_LAUNCHER_OUTPUT_STDOUT", "stdout" },
      { ANJUTA_LAUNCHER_OUTPUT_STDERR, "ANJUTA_LAUNCHER_OUTPUT_STDERR", "stderr" },
      { ANJUTA_LAUNCHER_OUTPUT_PTY, "ANJUTA_LAUNCHER_OUTPUT_PTY", "pty" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaLauncherOutputType"), values);
  }
  return etype;
}

/* enumerations from "anjuta-session.h" */
GType
anjuta_session_phase_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_SESSION_PHASE_START, "ANJUTA_SESSION_PHASE_START", "start" },
      { ANJUTA_SESSION_PHASE_FIRST, "ANJUTA_SESSION_PHASE_FIRST", "first" },
      { ANJUTA_SESSION_PHASE_NORMAL, "ANJUTA_SESSION_PHASE_NORMAL", "normal" },
      { ANJUTA_SESSION_PHASE_LAST, "ANJUTA_SESSION_PHASE_LAST", "last" },
      { ANJUTA_SESSION_PHASE_END, "ANJUTA_SESSION_PHASE_END", "end" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaSessionPhase"), values);
  }
  return etype;
}

/* enumerations from "anjuta-serializer.h" */
GType
anjuta_serializer_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_SERIALIZER_READ, "ANJUTA_SERIALIZER_READ", "read" },
      { ANJUTA_SERIALIZER_WRITE, "ANJUTA_SERIALIZER_WRITE", "write" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaSerializerMode"), values);
  }
  return etype;
}

/* enumerations from "anjuta-vcs-status.h" */
GType
anjuta_vcs_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_VCS_STATUS_MODIFIED, "ANJUTA_VCS_STATUS_MODIFIED", "modified" },
      { ANJUTA_VCS_STATUS_ADDED, "ANJUTA_VCS_STATUS_ADDED", "added" },
      { ANJUTA_VCS_STATUS_DELETED, "ANJUTA_VCS_STATUS_DELETED", "deleted" },
      { ANJUTA_VCS_STATUS_CONFLICTED, "ANJUTA_VCS_STATUS_CONFLICTED", "conflicted" },
      { ANJUTA_VCS_STATUS_UPTODATE, "ANJUTA_VCS_STATUS_UPTODATE", "uptodate" },
      { ANJUTA_VCS_STATUS_LOCKED, "ANJUTA_VCS_STATUS_LOCKED", "locked" },
      { ANJUTA_VCS_STATUS_MISSING, "ANJUTA_VCS_STATUS_MISSING", "missing" },
      { ANJUTA_VCS_STATUS_UNVERSIONED, "ANJUTA_VCS_STATUS_UNVERSIONED", "unversioned" },
      { ANJUTA_VCS_STATUS_IGNORED, "ANJUTA_VCS_STATUS_IGNORED", "ignored" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaVcsStatus"), values);
  }
  return etype;
}

#define __ANJUTA_ENUM_TYPES_C__

/* Generated data ends here */

==> anjuta-2.29.5.0.tar.gz: anjuta-2.29.5.0/libanjuta/anjuta-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "anjuta-enum-types.h"

/* enumerations from "anjuta-shell.h" */
GType
anjuta_shell_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_SHELL_ERROR_DOESNT_EXIST, "ANJUTA_SHELL_ERROR_DOESNT_EXIST", "exist" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaShellError"), values);
  }
  return etype;
}
GType
anjuta_shell_placement_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_SHELL_PLACEMENT_NONE, "ANJUTA_SHELL_PLACEMENT_NONE", "none" },
      { ANJUTA_SHELL_PLACEMENT_TOP, "ANJUTA_SHELL_PLACEMENT_TOP", "top" },
      { ANJUTA_SHELL_PLACEMENT_BOTTOM, "ANJUTA_SHELL_PLACEMENT_BOTTOM", "bottom" },
      { ANJUTA_SHELL_PLACEMENT_RIGHT, "ANJUTA_SHELL_PLACEMENT_RIGHT", "right" },
      { ANJUTA_SHELL_PLACEMENT_LEFT, "ANJUTA_SHELL_PLACEMENT_LEFT", "left" },
      { ANJUTA_SHELL_PLACEMENT_CENTER, "ANJUTA_SHELL_PLACEMENT_CENTER", "center" },
      { ANJUTA_SHELL_PLACEMENT_FLOATING, "ANJUTA_SHELL_PLACEMENT_FLOATING", "floating" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaShellPlacement"), values);
  }
  return etype;
}

/* enumerations from "anjuta-convert.h" */
GType
anjuta_convert_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_CONVERT_ERROR_AUTO_DETECTION_FAILED, "ANJUTA_CONVERT_ERROR_AUTO_DETECTION_FAILED", "failed" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaConvertError"), values);
  }
  return etype;
}

/* enumerations from "anjuta-plugin-description.h" */
GType
anjuta_plugin_description_parse_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_SYNTAX, "ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_SYNTAX", "syntax" },
      { ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_ESCAPES, "ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_ESCAPES", "escapes" },
      { ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_CHARS, "ANJUTA_PLUGIN_DESCRIPTION_PARSE_ERROR_INVALID_CHARS", "chars" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPluginDescriptionParseError"), values);
  }
  return etype;
}

/* enumerations from "anjuta-plugin-manager.h" */
GType
anjuta_plugin_manager_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY, "ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY", "missing-factory" },
      { ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN, "ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN", "error-unknown" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPluginManagerError"), values);
  }
  return etype;
}

/* enumerations from "anjuta-profile.h" */
GType
anjuta_profile_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PROFILE_ERROR_URI_READ_FAILED, "ANJUTA_PROFILE_ERROR_URI_READ_FAILED", "read-failed" },
      { ANJUTA_PROFILE_ERROR_URI_WRITE_FAILED, "ANJUTA_PROFILE_ERROR_URI_WRITE_FAILED", "write-failed" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaProfileError"), values);
  }
  return etype;
}

/* enumerations from "anjuta-preferences.h" */
GType
anjuta_property_object_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE, "ANJUTA_PROPERTY_OBJECT_TYPE_TOGGLE", "toggle" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_SPIN, "ANJUTA_PROPERTY_OBJECT_TYPE_SPIN", "spin" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY, "ANJUTA_PROPERTY_OBJECT_TYPE_ENTRY", "entry" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_COMBO, "ANJUTA_PROPERTY_OBJECT_TYPE_COMBO", "combo" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_TEXT, "ANJUTA_PROPERTY_OBJECT_TYPE_TEXT", "text" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_COLOR, "ANJUTA_PROPERTY_OBJECT_TYPE_COLOR", "color" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_FONT, "ANJUTA_PROPERTY_OBJECT_TYPE_FONT", "font" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_FILE, "ANJUTA_PROPERTY_OBJECT_TYPE_FILE", "file" },
      { ANJUTA_PROPERTY_OBJECT_TYPE_FOLDER, "ANJUTA_PROPERTY_OBJECT_TYPE_FOLDER", "folder" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPropertyObjectType"), values);
  }
  return etype;
}
GType
anjuta_property_data_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PROPERTY_DATA_TYPE_BOOL, "ANJUTA_PROPERTY_DATA_TYPE_BOOL", "bool" },
      { ANJUTA_PROPERTY_DATA_TYPE_INT, "ANJUTA_PROPERTY_DATA_TYPE_INT", "int" },
      { ANJUTA_PROPERTY_DATA_TYPE_TEXT, "ANJUTA_PROPERTY_DATA_TYPE_TEXT", "text" },
      { ANJUTA_PROPERTY_DATA_TYPE_COLOR, "ANJUTA_PROPERTY_DATA_TYPE_COLOR", "color" },
      { ANJUTA_PROPERTY_DATA_TYPE_FONT, "ANJUTA_PROPERTY_DATA_TYPE_FONT", "font" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaPropertyDataType"), values);
  }
  return etype;
}

/* enumerations from "anjuta-launcher.h" */
GType
anjuta_launcher_output_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_LAUNCHER_OUTPUT_STDOUT, "ANJUTA_LAUNCHER_OUTPUT_STDOUT", "stdout" },
      { ANJUTA_LAUNCHER_OUTPUT_STDERR, "ANJUTA_LAUNCHER_OUTPUT_STDERR", "stderr" },
      { ANJUTA_LAUNCHER_OUTPUT_PTY, "ANJUTA_LAUNCHER_OUTPUT_PTY", "pty" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaLauncherOutputType"), values);
  }
  return etype;
}

/* enumerations from "anjuta-session.h" */
GType
anjuta_session_phase_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_SESSION_PHASE_START, "ANJUTA_SESSION_PHASE_START", "start" },
      { ANJUTA_SESSION_PHASE_FIRST, "ANJUTA_SESSION_PHASE_FIRST", "first" },
      { ANJUTA_SESSION_PHASE_NORMAL, "ANJUTA_SESSION_PHASE_NORMAL", "normal" },
      { ANJUTA_SESSION_PHASE_LAST, "ANJUTA_SESSION_PHASE_LAST", "last" },
      { ANJUTA_SESSION_PHASE_END, "ANJUTA_SESSION_PHASE_END", "end" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaSessionPhase"), values);
  }
  return etype;
}

/* enumerations from "anjuta-serializer.h" */
GType
anjuta_serializer_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_SERIALIZER_READ, "ANJUTA_SERIALIZER_READ", "read" },
      { ANJUTA_SERIALIZER_WRITE, "ANJUTA_SERIALIZER_WRITE", "write" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaSerializerMode"), values);
  }
  return etype;
}

/* enumerations from "anjuta-vcs-status.h" */
GType
anjuta_vcs_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GFlagsValue values[] = {
      { ANJUTA_VCS_STATUS_MODIFIED, "ANJUTA_VCS_STATUS_MODIFIED", "modified" },
      { ANJUTA_VCS_STATUS_ADDED, "ANJUTA_VCS_STATUS_ADDED", "added" },
      { ANJUTA_VCS_STATUS_DELETED, "ANJUTA_VCS_STATUS_DELETED", "deleted" },
      { ANJUTA_VCS_STATUS_CONFLICTED, "ANJUTA_VCS_STATUS_CONFLICTED", "conflicted" },
      { ANJUTA_VCS_STATUS_UPTODATE, "ANJUTA_VCS_STATUS_UPTODATE", "uptodate" },
      { ANJUTA_VCS_STATUS_LOCKED, "ANJUTA_VCS_STATUS_LOCKED", "locked" },
      { ANJUTA_VCS_STATUS_MISSING, "ANJUTA_VCS_STATUS_MISSING", "missing" },
      { ANJUTA_VCS_STATUS_UNVERSIONED, "ANJUTA_VCS_STATUS_UNVERSIONED", "unversioned" },
      { ANJUTA_VCS_STATUS_IGNORED, "ANJUTA_VCS_STATUS_IGNORED", "ignored" },
      { 0, NULL, NULL }
    };
    etype = g_flags_register_static (g_intern_static_string ("AnjutaVcsStatus"), values);
  }
  return etype;
}

/* enumerations from "gbf-project.h" */
GType
if_if_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("if"), values);
  }
  return etype;
}

/* enumerations from "anjuta-project.h" */
GType
anjuta_project_node_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_PROJECT_UNKNOWN, "ANJUTA_PROJECT_UNKNOWN", "unknown" },
      { ANJUTA_PROJECT_GROUP, "ANJUTA_PROJECT_GROUP", "group" },
      { ANJUTA_PROJECT_TARGET, "ANJUTA_PROJECT_TARGET", "target" },
      { ANJUTA_PROJECT_SOURCE, "ANJUTA_PROJECT_SOURCE", "source" },
      { ANJUTA_PROJECT_VARIABLE, "ANJUTA_PROJECT_VARIABLE", "variable" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaProjectNodeType"), values);
  }
  return etype;
}
GType
anjuta_project_target_class_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { ANJUTA_TARGET_UNKNOWN, "ANJUTA_TARGET_UNKNOWN", "unknown" },
      { ANJUTA_TARGET_SHAREDLIB, "ANJUTA_TARGET_SHAREDLIB", "sharedlib" },
      { ANJUTA_TARGET_STATICLIB, "ANJUTA_TARGET_STATICLIB", "staticlib" },
      { ANJUTA_TARGET_EXECUTABLE, "ANJUTA_TARGET_EXECUTABLE", "executable" },
      { ANJUTA_TARGET_PYTHON, "ANJUTA_TARGET_PYTHON", "python" },
      { ANJUTA_TARGET_JAVA, "ANJUTA_TARGET_JAVA", "java" },
      { ANJUTA_TARGET_LISP, "ANJUTA_TARGET_LISP", "lisp" },
      { ANJUTA_TARGET_HEADER, "ANJUTA_TARGET_HEADER", "header" },
      { ANJUTA_TARGET_MAN, "ANJUTA_TARGET_MAN", "man" },
      { ANJUTA_TARGET_INFO, "ANJUTA_TARGET_INFO", "info" },
      { ANJUTA_TARGET_GENERIC, "ANJUTA_TARGET_GENERIC", "generic" },
      { ANJUTA_TARGET_DATA, "ANJUTA_TARGET_DATA", "data" },
      { ANJUTA_TARGET_EXTRA, "ANJUTA_TARGET_EXTRA", "extra" },
      { ANJUTA_TARGET_INTLTOOL, "ANJUTA_TARGET_INTLTOOL", "intltool" },
      { ANJUTA_TARGET_CONFIGURE, "ANJUTA_TARGET_CONFIGURE", "configure" },
      { ANJUTA_TARGET_IDL, "ANJUTA_TARGET_IDL", "idl" },
      { ANJUTA_TARGET_MKENUMS, "ANJUTA_TARGET_MKENUMS", "mkenums" },
      { ANJUTA_TARGET_GENMARSHAL, "ANJUTA_TARGET_GENMARSHAL", "genmarshal" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static (g_intern_static_string ("AnjutaProjectTargetClass"), values);
  }
  return etype;
}

#define __ANJUTA_ENUM_TYPES_C__

/* Generated data ends here */
